<?php

namespace Drupal\salesforce_past\EventSubscriber;

use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\salesforce\Event\SalesforceEvents;
use Drupal\salesforce_mapping\Event\SalesforcePushOpEvent;
use Drupal\salesforce_mapping\Event\SalesforcePushParamsEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Class SalesforcePastSubscriber.
 */
class SalesforcePastSubscriber implements EventSubscriberInterface {

  /**
   * The module handler.
   */
  protected $moduleHandler;

  /**
   * {@inheritDoc}
   */
  public function __construct(ModuleHandlerInterface $module_handler) {
    $this->moduleHandler = $module_handler;
  }

  /**
   * {@inheritDoc}
   */
  public function salesforcePushSuccess(SalesforcePushParamsEvent $event) {

    if (!$this->moduleHandler->moduleExists('past')) {
      return [];
    }

    $params = $event->getParams();

    $past = past_event_create('salesforce', 'api_request', 'Success');
    $past->addArgument('data', json_encode($params->getParams(), JSON_PRETTY_PRINT | JSON_UNESCAPED_SLASHES));
    $past->addArgument('mapping', $params->getMapping());
    $past->save();
  }

  /**
   * {@inheritDoc}
   */
  public function salesforcePushFail(SalesforcePushOpEvent $event) {

    if (!$this->moduleHandler->moduleExists('past')) {
      return [];
    }

    $past = past_event_create('salesforce', 'api_request', 'Failed');
    $past->addArgument('mapping', $event->getMapping());
    $past->save();
  }

  /**
   * @inheritDoc
   */
  public static function getSubscribedEvents() {
    return [
      SalesforceEvents::PUSH_SUCCESS => 'salesforcePushSuccess',
      SalesforceEvents::PUSH_FAIL => 'salesforcePushFail',
    ];
  }

}